========
MUPHOTEN
========


.. image:: https://img.shields.io/pypi/v/muphoten.svg
        :target: https://pypi.python.org/pypi/muphoten

.. image:: https://img.shields.io/travis/PAduverne/muphoten.svg
        :target: https://travis-ci.com/PAduverne/muphoten

.. image:: https://readthedocs.org/projects/muphoten/badge/?version=latest
        :target: https://muphoten.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status




A photometry tool for transient astromy, design for network of telescopes


* Free software: GNU General Public License v3
* Documentation: https://muphoten.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
